# coding: utf-8

"""
    Freestyle Sandboxes

     Freestyle Sandboxes lets you deploy your users or AIs code. **Get your API Key at [admin.freestyle.sh](https://admin.freestyle.sh)**  They are broken up into core 5 categories: [Web](#tag/web), [Execute](#tag/execute), [Cloudstate](#tag/cloudstate), [Git](#tag/git), and [Domains](#tag/domains).  [Web](#tag/web): Send us the code for the website, we'll provision the certificates and get it hosted  [Execute](#tag/execute): Send us a function, we'll run it and send you the output  [Cloudstate](#tag/cloudstate): Our Opensource JavaScript Runtime used for cloud functions with persistent state  [Domains](#tag/domains): Manage your domains, including verification and listing  [Git](#tag/git): Manage your git repositories 

    The version of the OpenAPI document: 0.1.0
    Contact: ben@freestyle.sh
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class DevServerRequest(BaseModel):
    """
    DevServerRequest
    """ # noqa: E501
    dev_command: Optional[StrictStr] = Field(default=None, alias="devCommand")
    pre_dev_command_once: Optional[StrictStr] = Field(default=None, alias="preDevCommandOnce")
    base_id: Optional[StrictStr] = Field(default=None, alias="baseId")
    env_vars: Optional[Dict[str, StrictStr]] = Field(default=None, alias="envVars")
    repo_id: Optional[StrictStr] = Field(default=None, alias="repoId")
    compute_class: Optional[StrictStr] = Field(default='high', alias="computeClass")
    timeout: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="Timeout in seconds")
    domain: Optional[StrictStr] = None
    repo: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["devCommand", "preDevCommandOnce", "baseId", "envVars", "repoId", "computeClass", "timeout", "domain", "repo"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DevServerRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if dev_command (nullable) is None
        # and model_fields_set contains the field
        if self.dev_command is None and "dev_command" in self.model_fields_set:
            _dict['devCommand'] = None

        # set to None if pre_dev_command_once (nullable) is None
        # and model_fields_set contains the field
        if self.pre_dev_command_once is None and "pre_dev_command_once" in self.model_fields_set:
            _dict['preDevCommandOnce'] = None

        # set to None if base_id (nullable) is None
        # and model_fields_set contains the field
        if self.base_id is None and "base_id" in self.model_fields_set:
            _dict['baseId'] = None

        # set to None if repo_id (nullable) is None
        # and model_fields_set contains the field
        if self.repo_id is None and "repo_id" in self.model_fields_set:
            _dict['repoId'] = None

        # set to None if compute_class (nullable) is None
        # and model_fields_set contains the field
        if self.compute_class is None and "compute_class" in self.model_fields_set:
            _dict['computeClass'] = None

        # set to None if timeout (nullable) is None
        # and model_fields_set contains the field
        if self.timeout is None and "timeout" in self.model_fields_set:
            _dict['timeout'] = None

        # set to None if domain (nullable) is None
        # and model_fields_set contains the field
        if self.domain is None and "domain" in self.model_fields_set:
            _dict['domain'] = None

        # set to None if repo (nullable) is None
        # and model_fields_set contains the field
        if self.repo is None and "repo" in self.model_fields_set:
            _dict['repo'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DevServerRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "devCommand": obj.get("devCommand"),
            "preDevCommandOnce": obj.get("preDevCommandOnce"),
            "baseId": obj.get("baseId"),
            "envVars": obj.get("envVars"),
            "repoId": obj.get("repoId"),
            "computeClass": obj.get("computeClass") if obj.get("computeClass") is not None else 'high',
            "timeout": obj.get("timeout"),
            "domain": obj.get("domain"),
            "repo": obj.get("repo")
        })
        return _obj





# coding: utf-8

"""
    Freestyle Sandboxes

     Freestyle Sandboxes lets you deploy your users or AIs code. **Get your API Key at [admin.freestyle.sh](https://admin.freestyle.sh)**  They are broken up into core 5 categories: [Web](#tag/web), [Execute](#tag/execute), [Cloudstate](#tag/cloudstate), [Git](#tag/git), and [Domains](#tag/domains).  [Web](#tag/web): Send us the code for the website, we'll provision the certificates and get it hosted  [Execute](#tag/execute): Send us a function, we'll run it and send you the output  [Cloudstate](#tag/cloudstate): Our Opensource JavaScript Runtime used for cloud functions with persistent state  [Domains](#tag/domains): Manage your domains, including verification and listing  [Git](#tag/git): Manage your git repositories 

    The version of the OpenAPI document: 0.1.0
    Contact: ben@freestyle.sh
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List
from _openapi_client.models.handle_create_git_trigger_request_action import HandleCreateGitTriggerRequestAction
from _openapi_client.models.handle_create_git_trigger_request_trigger import HandleCreateGitTriggerRequestTrigger
from typing import Optional, Set
from typing_extensions import Self

class GitRepositoryTrigger(BaseModel):
    """
    GitRepositoryTrigger
    """ # noqa: E501
    repository_id: StrictStr = Field(alias="repositoryId")
    trigger: HandleCreateGitTriggerRequestTrigger
    action: HandleCreateGitTriggerRequestAction
    managed: StrictBool
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    __properties: ClassVar[List[str]] = ["repositoryId", "trigger", "action", "managed", "id", "createdAt"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GitRepositoryTrigger from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of trigger
        if self.trigger:
            _dict['trigger'] = self.trigger.to_dict()
        # override the default output from pydantic by calling `to_dict()` of action
        if self.action:
            _dict['action'] = self.action.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GitRepositoryTrigger from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "repositoryId": obj.get("repositoryId"),
            "trigger": HandleCreateGitTriggerRequestTrigger.from_dict(obj["trigger"]) if obj.get("trigger") is not None else None,
            "action": HandleCreateGitTriggerRequestAction.from_dict(obj["action"]) if obj.get("action") is not None else None,
            "managed": obj.get("managed"),
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt")
        })
        return _obj





from _openapi_client.models.freestyle_execute_script_params_configuration import (
    FreestyleExecuteScriptParamsConfiguration,
)
from typing import Tuple, Callable
from google.genai import types

# from google.genai import Content
from freestyle import Freestyle


def execute_tool(
    apiKey: str, params: FreestyleExecuteScriptParamsConfiguration = None
) -> Tuple[types.Tool, Callable[[types.Content], None]]:
    freestyle = Freestyle(apiKey)

    def codeExecutor(completion: types.Content):
        calls = [t for t in completion.parts if t.function_call.name == "executeCode"]

        if not calls:
            return None

        results = [
            # freestyle.executeScript(
            #     json.loads(call.function_call.args)["script"], params
            # )
            freestyle.execute_script(call.function_call.args["script"], params)
            for call in calls
        ]

        return [
            types.FunctionResponseDict(
                id=call.function_call.id,
                name=call.function_call.name,
                response=result.to_str(),
            )
            for result, call in zip(results, calls)
        ]

        # return [
        #     types.Tool(
        #         content=result.to_str(), role="tool", tool_call_id=call.id
        #     )
        #     for result, call in zip(results, calls)
        # ]

    return (execute_tool_definition(params), codeExecutor)


def execute_tool_definition(
    params: FreestyleExecuteScriptParamsConfiguration = None,
) -> types.Tool:
    params = params or FreestyleExecuteScriptParamsConfiguration()
    env_vars = list((params.env_vars or {}).keys())
    node_modules = list((params.node_modules or {}).keys())

    description = (
        "Execute a JavaScript or TypeScript script.\n"
        + (
            f"You can use the following environment variables: {', '.join(env_vars)}\n"
            if env_vars
            else ""
        )
        + (
            f"You can use the following node modules: {', '.join(node_modules)}"
            if node_modules
            else "You cannot use any node modules."
        )
    )

    return types.Tool(
        function_declarations=[
            types.FunctionDeclaration(
                name="executeCode",
                description=description,
                parameters={
                    "type": "object",
                    "required": ["script"],
                    "properties": {
                        "script": {
                            "type": "string",
                            "description": (
                                "The JavaScript or TypeScript script to execute, must be in the format of:\n\n"
                                'import { someModule } from "someModule";\n'
                                "export default () => {\n"
                                "   ... your code here ...\n"
                                "   return output;\n"
                                "}\n\n"
                                "or for async functions:\n\n"
                                'import { someModule } from "someModule";\n\n'
                                "export default async () => {\n"
                                "    ... your code here ...\n"
                                "    return output;\n"
                                "}\n"
                            ),
                        }
                    },
                },
            )
        ]
    )



# coding: utf-8

"""
    Freestyle Sandboxes

     Freestyle Sandboxes lets you deploy your users or AIs code. **Get your API Key at [admin.freestyle.sh](https://admin.freestyle.sh)**  They are broken up into core 5 categories: [Web](#tag/web), [Execute](#tag/execute), [Cloudstate](#tag/cloudstate), [Git](#tag/git), and [Domains](#tag/domains).  [Web](#tag/web): Send us the code for the website, we'll provision the certificates and get it hosted  [Execute](#tag/execute): Send us a function, we'll run it and send you the output  [Cloudstate](#tag/cloudstate): Our Opensource JavaScript Runtime used for cloud functions with persistent state  [Domains](#tag/domains): Manage your domains, including verification and listing  [Git](#tag/git): Manage your git repositories 

    The version of the OpenAPI document: 0.1.0
    Contact: ben@freestyle.sh
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Visibility(str, Enum):
    """
    Visibility
    """

    """
    allowed enum values
    """
    PUBLIC = 'public'
    PRIVATE = 'private'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Visibility from a JSON string"""
        return cls(json.loads(json_str))





from _openapi_client.models.freestyle_execute_script_params_configuration import (
    FreestyleExecuteScriptParamsConfiguration,
)
from freestyle.client import Freestyle
from typing import Tuple, Callable
from freestyle.gemini import execute_tool_definition as gemini_execute_tool_definition
from freestyle.openai import execute_tool_definition as openai_execute_tool_definition

EXECUTE_TOOL_NAME = "executeCode"


def execute_tool_executor(
    apiKey: str, params: FreestyleExecuteScriptParamsConfiguration = None
) -> Callable:
    freestyle = Freestyle(apiKey)

    async def toolExecutor(
        function_name, tool_call_id, args, llm, context, result_callback
    ):
        if function_name == "executeCode":
            script = args["script"]
            execution = freestyle.execute_script(script, params)
            await result_callback(execution.to_json())
        else:
            await result_callback(None)

    return toolExecutor


def execute_tool_gemini(
    apiKey: str, params: FreestyleExecuteScriptParamsConfiguration = None
) -> Tuple[str, Callable]:
    return gemini_execute_tool_definition(params), execute_tool_executor(apiKey, params)


def execute_tool_openai(
    apiKey: str, params: FreestyleExecuteScriptParamsConfiguration = None
) -> Tuple[str, Callable]:
    return openai_execute_tool_definition(params), execute_tool_executor(apiKey, params)



# coding: utf-8

# flake8: noqa

"""
    Freestyle Sandboxes

     Freestyle Sandboxes lets you deploy your users or AIs code. **Get your API Key at [admin.freestyle.sh](https://admin.freestyle.sh)**  They are broken up into core 5 categories: [Web](#tag/web), [Execute](#tag/execute), [Cloudstate](#tag/cloudstate), [Git](#tag/git), and [Domains](#tag/domains).  [Web](#tag/web): Send us the code for the website, we'll provision the certificates and get it hosted  [Execute](#tag/execute): Send us a function, we'll run it and send you the output  [Cloudstate](#tag/cloudstate): Our Opensource JavaScript Runtime used for cloud functions with persistent state  [Domains](#tag/domains): Manage your domains, including verification and listing  [Git](#tag/git): Manage your git repositories 

    The version of the OpenAPI document: 0.1.0
    Contact: ben@freestyle.sh
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from _openapi_client.api.certs_api import CertsApi
from _openapi_client.api.cloudstate_api import CloudstateApi
from _openapi_client.api.dns_api import DNSApi
from _openapi_client.api.deprecated_api import DeprecatedApi
from _openapi_client.api.dev_servers_api import DevServersApi
from _openapi_client.api.domains_api import DomainsApi
from _openapi_client.api.execute_api import ExecuteApi
from _openapi_client.api.git_api import GitApi
from _openapi_client.api.observability_api import ObservabilityApi
from _openapi_client.api.web_api import WebApi

# import ApiClient
from _openapi_client.api_response import ApiResponse
from _openapi_client.api_client import ApiClient
from _openapi_client.configuration import Configuration
from _openapi_client.exceptions import OpenApiException
from _openapi_client.exceptions import ApiTypeError
from _openapi_client.exceptions import ApiValueError
from _openapi_client.exceptions import ApiKeyError
from _openapi_client.exceptions import ApiAttributeError
from _openapi_client.exceptions import ApiException

# import models into sdk package
from _openapi_client.models.access_level import AccessLevel
from _openapi_client.models.access_token_info import AccessTokenInfo
from _openapi_client.models.accessible_repository import AccessibleRepository
from _openapi_client.models.behavior import Behavior
from _openapi_client.models.blob import Blob
from _openapi_client.models.blob_encoding import BlobEncoding
from _openapi_client.models.blob_object import BlobObject
from _openapi_client.models.commit_object import CommitObject
from _openapi_client.models.commit_parent import CommitParent
from _openapi_client.models.commit_tree import CommitTree
from _openapi_client.models.create_domain_mapping_request import CreateDomainMappingRequest
from _openapi_client.models.create_record_params import CreateRecordParams
from _openapi_client.models.create_repo_request import CreateRepoRequest
from _openapi_client.models.create_repo_source import CreateRepoSource
from _openapi_client.models.create_repository_request import CreateRepositoryRequest
from _openapi_client.models.create_repository_response_success import CreateRepositoryResponseSuccess
from _openapi_client.models.created_token import CreatedToken
from _openapi_client.models.custom_build_options import CustomBuildOptions
from _openapi_client.models.deployment_build_options import DeploymentBuildOptions
from _openapi_client.models.deployment_log_entry import DeploymentLogEntry
from _openapi_client.models.deployment_source import DeploymentSource
from _openapi_client.models.deployment_source_one_of import DeploymentSourceOneOf
from _openapi_client.models.deployment_source_one_of1 import DeploymentSourceOneOf1
from _openapi_client.models.deployment_source_one_of2 import DeploymentSourceOneOf2
from _openapi_client.models.deployment_state import DeploymentState
from _openapi_client.models.describe_permission_response_success import DescribePermissionResponseSuccess
from _openapi_client.models.dev_server import DevServer
from _openapi_client.models.dev_server_one_of import DevServerOneOf
from _openapi_client.models.dev_server_request import DevServerRequest
from _openapi_client.models.dev_server_status_request import DevServerStatusRequest
from _openapi_client.models.dev_server_watch_files_request import DevServerWatchFilesRequest
from _openapi_client.models.directory import Directory
from _openapi_client.models.directory_entry import DirectoryEntry
from _openapi_client.models.directory_entry_entries_inner import DirectoryEntryEntriesInner
from _openapi_client.models.dns_record import DnsRecord
from _openapi_client.models.dns_record_data import DnsRecordData
from _openapi_client.models.dns_record_kind import DnsRecordKind
from _openapi_client.models.domain_verification_request import DomainVerificationRequest
from _openapi_client.models.exec_request import ExecRequest
from _openapi_client.models.execute_log_entry import ExecuteLogEntry
from _openapi_client.models.execute_run_info import ExecuteRunInfo
from _openapi_client.models.execute_run_state import ExecuteRunState
from _openapi_client.models.file import File
from _openapi_client.models.file_entry import FileEntry
from _openapi_client.models.file_read_content import FileReadContent
from _openapi_client.models.freestyle_cloudstate_deploy_configuration import FreestyleCloudstateDeployConfiguration
from _openapi_client.models.freestyle_cloudstate_deploy_error_response import FreestyleCloudstateDeployErrorResponse
from _openapi_client.models.freestyle_cloudstate_deploy_request import FreestyleCloudstateDeployRequest
from _openapi_client.models.freestyle_cloudstate_deploy_success_response import FreestyleCloudstateDeploySuccessResponse
from _openapi_client.models.freestyle_delete_domain_verification_request import FreestyleDeleteDomainVerificationRequest
from _openapi_client.models.freestyle_deploy_web_configuration import FreestyleDeployWebConfiguration
from _openapi_client.models.freestyle_deploy_web_error_response import FreestyleDeployWebErrorResponse
from _openapi_client.models.freestyle_deploy_web_payload import FreestyleDeployWebPayload
from _openapi_client.models.freestyle_deploy_web_payload_v2 import FreestyleDeployWebPayloadV2
from _openapi_client.models.freestyle_deploy_web_success_response_v2 import FreestyleDeployWebSuccessResponseV2
from _openapi_client.models.freestyle_domain_verification_request import FreestyleDomainVerificationRequest
from _openapi_client.models.freestyle_execute_script_params import FreestyleExecuteScriptParams
from _openapi_client.models.freestyle_execute_script_params_configuration import FreestyleExecuteScriptParamsConfiguration
from _openapi_client.models.freestyle_execute_script_result_success import FreestyleExecuteScriptResultSuccess
from _openapi_client.models.freestyle_file import FreestyleFile
from _openapi_client.models.freestyle_get_logs_response import FreestyleGetLogsResponse
from _openapi_client.models.freestyle_java_script_log import FreestyleJavaScriptLog
from _openapi_client.models.freestyle_log_response_object import FreestyleLogResponseObject
from _openapi_client.models.freestyle_network_permission import FreestyleNetworkPermission
from _openapi_client.models.freestyle_network_permission_one_of import FreestyleNetworkPermissionOneOf
from _openapi_client.models.freestyle_network_permission_one_of1 import FreestyleNetworkPermissionOneOf1
from _openapi_client.models.freestyle_verify_domain_request import FreestyleVerifyDomainRequest
from _openapi_client.models.freestyle_verify_domain_request_one_of import FreestyleVerifyDomainRequestOneOf
from _openapi_client.models.git_commit_push_request import GitCommitPushRequest
from _openapi_client.models.git_contents import GitContents
from _openapi_client.models.git_contents_dir_entry_item import GitContentsDirEntryItem
from _openapi_client.models.git_identity import GitIdentity
from _openapi_client.models.git_reference import GitReference
from _openapi_client.models.git_repository_trigger import GitRepositoryTrigger
from _openapi_client.models.git_trigger import GitTrigger
from _openapi_client.models.git_trigger_action import GitTriggerAction
from _openapi_client.models.grant_permission_request import GrantPermissionRequest
from _openapi_client.models.handle_create_git_trigger200_response import HandleCreateGitTrigger200Response
from _openapi_client.models.handle_create_git_trigger_request import HandleCreateGitTriggerRequest
from _openapi_client.models.handle_create_git_trigger_request_action import HandleCreateGitTriggerRequestAction
from _openapi_client.models.handle_create_git_trigger_request_action_one_of import HandleCreateGitTriggerRequestActionOneOf
from _openapi_client.models.handle_create_git_trigger_request_trigger import HandleCreateGitTriggerRequestTrigger
from _openapi_client.models.handle_create_git_trigger_request_trigger_one_of import HandleCreateGitTriggerRequestTriggerOneOf
from _openapi_client.models.handle_create_record200_response import HandleCreateRecord200Response
from _openapi_client.models.handle_create_repo_request import HandleCreateRepoRequest
from _openapi_client.models.handle_delete_domain_verification200_response import HandleDeleteDomainVerification200Response
from _openapi_client.models.handle_dev_server_status200_response import HandleDevServerStatus200Response
from _openapi_client.models.handle_ephemeral_dev_server200_response import HandleEphemeralDevServer200Response
from _openapi_client.models.handle_exec_on_ephemeral_dev_server200_response import HandleExecOnEphemeralDevServer200Response
from _openapi_client.models.handle_execute_script200_response import HandleExecuteScript200Response
from _openapi_client.models.handle_execute_script400_response import HandleExecuteScript400Response
from _openapi_client.models.handle_get_execute_run200_response import HandleGetExecuteRun200Response
from _openapi_client.models.handle_get_execute_run401_response import HandleGetExecuteRun401Response
from _openapi_client.models.handle_get_execute_run404_response import HandleGetExecuteRun404Response
from _openapi_client.models.handle_get_execute_run500_response import HandleGetExecuteRun500Response
from _openapi_client.models.handle_list_domain_verification_requests200_response_inner import HandleListDomainVerificationRequests200ResponseInner
from _openapi_client.models.handle_list_domains200_response_inner import HandleListDomains200ResponseInner
from _openapi_client.models.handle_list_execute_runs200_response import HandleListExecuteRuns200Response
from _openapi_client.models.handle_list_git_triggers200_response import HandleListGitTriggers200Response
from _openapi_client.models.handle_list_identities200_response import HandleListIdentities200Response
from _openapi_client.models.handle_list_records400_response import HandleListRecords400Response
from _openapi_client.models.handle_list_repositories200_response import HandleListRepositories200Response
from _openapi_client.models.handle_list_web_deploys200_response import HandleListWebDeploys200Response
from _openapi_client.models.handle_read_file_from_ephemeral_dev_server200_response import HandleReadFileFromEphemeralDevServer200Response
from _openapi_client.models.handle_read_file_from_ephemeral_dev_server200_response_content import HandleReadFileFromEphemeralDevServer200ResponseContent
from _openapi_client.models.handle_read_file_from_ephemeral_dev_server200_response_content_one_of import HandleReadFileFromEphemeralDevServer200ResponseContentOneOf
from _openapi_client.models.handle_read_file_from_ephemeral_dev_server200_response_content_one_of1 import HandleReadFileFromEphemeralDevServer200ResponseContentOneOf1
from _openapi_client.models.handle_shutdown_dev_server200_response import HandleShutdownDevServer200Response
from _openapi_client.models.handle_verify_wildcard200_response import HandleVerifyWildcard200Response
from _openapi_client.models.handle_write_file_from_ephemeral_dev_server200_response import HandleWriteFileFromEphemeralDevServer200Response
from _openapi_client.models.list_git_tokens_response_success import ListGitTokensResponseSuccess
from _openapi_client.models.list_permission_response_success import ListPermissionResponseSuccess
from _openapi_client.models.list_records_response import ListRecordsResponse
from _openapi_client.models.network_permission_data import NetworkPermissionData
from _openapi_client.models.read_file_ephemeral_dev_server_responses import ReadFileEphemeralDevServerResponses
from _openapi_client.models.read_file_request import ReadFileRequest
from _openapi_client.models.repository_info import RepositoryInfo
from _openapi_client.models.revoke_git_token_request import RevokeGitTokenRequest
from _openapi_client.models.shutdown_dev_server_request import ShutdownDevServerRequest
from _openapi_client.models.signature import Signature
from _openapi_client.models.source import Source
from _openapi_client.models.tag_object import TagObject
from _openapi_client.models.tag_target import TagTarget
from _openapi_client.models.tree import Tree
from _openapi_client.models.tree_entry import TreeEntry
from _openapi_client.models.tree_object import TreeObject
from _openapi_client.models.update_permission_request import UpdatePermissionRequest
from _openapi_client.models.visibility import Visibility
from _openapi_client.models.write_file_request import WriteFileRequest



from _openapi_client import (
    Configuration,
    ApiClient,
    FreestyleExecuteScriptParamsConfiguration,
    ExecuteApi,
    FreestyleExecuteScriptParams,
    FreestyleDeployWebPayloadV2,
    WebApi,
    DeploymentSource,
    FreestyleDeployWebConfiguration,
    GitApi,
)


class Freestyle:
    def __init__(self, token: str, baseUrl: str = "https://api.freestyle.sh"):
        self.token = token
        self.baseUrl = baseUrl

    def _client(self):
        configuration = Configuration()
        configuration.host = self.baseUrl

        client = ApiClient(configuration)
        client.set_default_header("Authorization", f"Bearer {self.token}")
        return client

    def execute_script(
        self, code: str, config: FreestyleExecuteScriptParamsConfiguration = None
    ):
        api = ExecuteApi(self._client())
        return api.handle_execute_script(
            FreestyleExecuteScriptParams(script=code, config=config)
        )

    def deploy_web(
        self,
        src: DeploymentSource,
        config: FreestyleDeployWebConfiguration = None,
    ):
        api = WebApi(self._client())
        return api.handle_deploy_web_v2(
            FreestyleDeployWebPayloadV2(source=src, config=config)
        )

    def list_git_identities(
        self, limit: int = 100, offset: int = 0, include_managed: bool = False
    ):
        api = GitApi(self._client())
        return api.handle_list_identities(
            limit=limit, offset=offset, include_managed=include_managed
        )

    def cretate_git_identity(self):
        api = GitApi(self._client())
        return api.handle_create_identity()

    def delete_git_identity(self, identity_id: str):
        api = GitApi(self._client())
        return api.handle_delete_identity(identity_id)

    def list_repository_permissions_for_identity(
        self, identity_id: str, limit: int = 100, offset: int = 0
    ):
        api = GitApi(self._client())
        return api.handle_list_repository_permissions_by_identity(
            identity_id=identity_id, limit=limit, offset=offset
        )

    def grant_permission_to_identity(self, identity_id: str, repository_id: str):
        api = GitApi(self._client())
        return api.handle_grant_permission_to_identity(
            identity_id=identity_id, repository_id=repository_id
        )

    def revoke_permission_from_identity(self, identity_id: str, repository_id: str):
        api = GitApi(self._client())
        return api.handle_revoke_permission_from_identity(
            identity_id=identity_id, repository_id=repository_id
        )

    def update_permission_for_identity(
        self, identity_id: str, repository_id: str, permission: str
    ):
        api = GitApi(self._client())
        return api.handle_update_permission_for_identity(
            identity_id=identity_id, repository_id=repository_id, permission=permission
        )

    def list_access_tokens_for_identity(
        self, identity_id: str, limit: int = 100, offset: int = 0
    ):
        api = GitApi(self._client())
        return api.handle_list_access_tokens_by_identity(
            identity_id=identity_id, limit=limit, offset=offset
        )

    def create_access_token_for_identity(
        self, identity_id: str, name: str = "Unnamed Access Token", expires_in: int = 0
    ):
        api = GitApi(self._client())
        return api.handle_create_access_token_for_identity(
            identity_id=identity_id, name=name, expires_in=expires_in
        )

    def revoke_access_token_for_identity(self, identity_id: str, access_token_id: str):
        api = GitApi(self._client())
        return api.handle_revoke_access_token_for_identity(
            identity_id=identity_id, access_token_id=access_token_id
        )

    def list_repositories(self, limit: int = 100, offset: int = 0):
        api = GitApi(self._client())
        return api.handle_list_repositories(limit=limit, offset=offset)

    def create_repository(self, name: str = "Unnamed Repository", private: bool = True):
        api = GitApi(self._client())
        return api.handle_create_repository(name=name, private=private)

    def delete_repository(self, repository_id: str):
        api = GitApi(self._client())
        return api.handle_delete_repository(repository_id=repository_id)
